Getting GooseBib
================

Using conda
-----------

.. code-block:: none

  conda install -c conda-forge goosebib

Using PyPi
----------

.. code-block:: none

  python -m pip install GooseBib

From source
-----------

.. code-block:: none

  git checkout https://github.com/tdegeus/GooseBib.git
  cd GooseBib

  python -m pip install .
